Separated data, controller, display layers
-------

**Description:**

The application should separate data, controller, and display layers in order to make your
application more clear and understandable in terms of abstraction due to separation.

Whenever your application is more organized and abstracted it is much easier to implement 
less flawed security controls.

 
**Solution:**

Make sure your different type of data layers are separated in your application.

The separation of these different layers is also know as a design pattern which goes 
by the name MVC (model, view, controller).
